@@ -1,43 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 2005-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the demonstration applications of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** In addition, as a special exception, Nokia gives you certain
+** additional rights. These rights are described in the Nokia Qt LGPL
+** Exception version 1.0, included in the file LGPL_EXCEPTION.txt in this
+** package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -206,7 +204,7 @@ inline static bool x_less_than(const QPointF &p1, const QPointF &p2)
 
 void GradientEditor::pointsUpdated()
 {
-    double w = m_alpha_shade->width();
+    qreal w = m_alpha_shade->width();
 
     QGradientStops stops;
 
@@ -220,7 +218,7 @@ void GradientEditor::pointsUpdated()
     qSort(points.begin(), points.end(), x_less_than);
 
     for (int i=0; i<points.size(); ++i) {
-        double x = int(points.at(i).x());
+        qreal x = int(points.at(i).x());
         if (i < points.size() - 1 && x == points.at(i+1).x())
             continue;
         QColor color((0x00ff0000 & m_red_shade->colorAt(int(x))) >> 16,
@@ -252,13 +250,13 @@ void GradientEditor::setGradientStops(const QGradientStops &stops)
 {
     QPolygonF pts_red, pts_green, pts_blue, pts_alpha;
 
-    double h_red = m_red_shade->height();
-    double h_green = m_green_shade->height();
-    double h_blue = m_blue_shade->height();
-    double h_alpha = m_alpha_shade->height();
+    qreal h_red = m_red_shade->height();
+    qreal h_green = m_green_shade->height();
+    qreal h_blue = m_blue_shade->height();
+    qreal h_alpha = m_alpha_shade->height();
 
     for (int i=0; i<stops.size(); ++i) {
-        double pos = stops.at(i).first;
+        qreal pos = stops.at(i).first;
         QRgb color = stops.at(i).second.rgba();
         pts_red << QPointF(pos * m_red_shade->width(), h_red - qRed(color) * h_red / 255);
         pts_green << QPointF(pos * m_green_shade->width(), h_green - qGreen(color) * h_green / 255);
@@ -276,52 +274,48 @@ void GradientEditor::setGradientStops(const QGradientStops &stops)
 GradientWidget::GradientWidget(QWidget *parent)
     : QWidget(parent)
 {
-    setWindowTitle("Gradients");
+    setWindowTitle(tr("Gradients"));
 
     m_renderer = new GradientRenderer(this);
 
     QGroupBox *mainGroup = new QGroupBox(this);
-    mainGroup->setTitle("Gradients");
+    mainGroup->setTitle(tr("Gradients"));
 
     QGroupBox *editorGroup = new QGroupBox(mainGroup);
-    editorGroup->setAttribute(Qt::WA_ContentsPropagated);
-    editorGroup->setTitle("Color Editor");
+    editorGroup->setTitle(tr("Color Editor"));
     m_editor = new GradientEditor(editorGroup);
 
     QGroupBox *typeGroup = new QGroupBox(mainGroup);
-    typeGroup->setAttribute(Qt::WA_ContentsPropagated);
-    typeGroup->setTitle("Gradient Type");
-    m_linearButton = new QRadioButton("Linear Gradient", typeGroup);
-    m_radialButton = new QRadioButton("Radial Gradient", typeGroup);
-    m_conicalButton = new QRadioButton("Conical Gradient", typeGroup);
+    typeGroup->setTitle(tr("Gradient Type"));
+    m_linearButton = new QRadioButton(tr("Linear Gradient"), typeGroup);
+    m_radialButton = new QRadioButton(tr("Radial Gradient"), typeGroup);
+    m_conicalButton = new QRadioButton(tr("Conical Gradient"), typeGroup);
 
     QGroupBox *spreadGroup = new QGroupBox(mainGroup);
-    spreadGroup->setAttribute(Qt::WA_ContentsPropagated);
-    spreadGroup->setTitle("Spread Method");
-    m_padSpreadButton = new QRadioButton("Pad Spread", spreadGroup);
-    m_reflectSpreadButton = new QRadioButton("Reflect Spread", spreadGroup);
-    m_repeatSpreadButton = new QRadioButton("Repeat Spread", spreadGroup);
+    spreadGroup->setTitle(tr("Spread Method"));
+    m_padSpreadButton = new QRadioButton(tr("Pad Spread"), spreadGroup);
+    m_reflectSpreadButton = new QRadioButton(tr("Reflect Spread"), spreadGroup);
+    m_repeatSpreadButton = new QRadioButton(tr("Repeat Spread"), spreadGroup);
 
     QGroupBox *defaultsGroup = new QGroupBox(mainGroup);
-    defaultsGroup->setAttribute(Qt::WA_ContentsPropagated);
-    defaultsGroup->setTitle("Defaults");
-    QPushButton *default1Button = new QPushButton("1", defaultsGroup);
-    QPushButton *default2Button = new QPushButton("2", defaultsGroup);
-    QPushButton *default3Button = new QPushButton("3", defaultsGroup);
-    QPushButton *default4Button = new QPushButton("Reset", editorGroup);
+    defaultsGroup->setTitle(tr("Defaults"));
+    QPushButton *default1Button = new QPushButton(tr("1"), defaultsGroup);
+    QPushButton *default2Button = new QPushButton(tr("2"), defaultsGroup);
+    QPushButton *default3Button = new QPushButton(tr("3"), defaultsGroup);
+    QPushButton *default4Button = new QPushButton(tr("Reset"), editorGroup);
 
     QPushButton *showSourceButton = new QPushButton(mainGroup);
-    showSourceButton->setText("Show Source");
+    showSourceButton->setText(tr("Show Source"));
 #ifdef QT_OPENGL_SUPPORT
     QPushButton *enableOpenGLButton = new QPushButton(mainGroup);
-    enableOpenGLButton->setText("Use OpenGL");
+    enableOpenGLButton->setText(tr("Use OpenGL"));
     enableOpenGLButton->setCheckable(true);
     enableOpenGLButton->setChecked(m_renderer->usesOpenGL());
     if (!QGLFormat::hasOpenGL())
         enableOpenGLButton->hide();
 #endif
     QPushButton *whatsThisButton = new QPushButton(mainGroup);
-    whatsThisButton->setText("What's This?");
+    whatsThisButton->setText(tr("What's This?"));
     whatsThisButton->setCheckable(true);
 
     // Layouts
@@ -380,7 +374,7 @@ GradientWidget::GradientWidget(QWidget *parent)
     connect(showSourceButton, SIGNAL(clicked()), m_renderer, SLOT(showSource()));
 #ifdef QT_OPENGL_SUPPORT
     connect(enableOpenGLButton, SIGNAL(clicked(bool)), m_renderer, SLOT(enableOpenGL(bool)));
-#endif
+#endif    
     connect(whatsThisButton, SIGNAL(clicked(bool)), m_renderer, SLOT(setDescriptionEnabled(bool)));
     connect(whatsThisButton, SIGNAL(clicked(bool)),
             m_renderer->hoverPoints(), SLOT(setDisabled(bool)));
@@ -389,8 +383,8 @@ GradientWidget::GradientWidget(QWidget *parent)
     connect(m_renderer, SIGNAL(descriptionEnabledChanged(bool)),
             m_renderer->hoverPoints(), SLOT(setDisabled(bool)));
 
-    m_renderer->loadSourceFile(":res/gradients.cpp");
-    m_renderer->loadDescription(":res/gradients.html");
+    m_renderer->loadSourceFile(":res/gradients/gradients.cpp");
+    m_renderer->loadDescription(":res/gradients/gradients.html");
 
     QTimer::singleShot(50, this, SLOT(setDefault1()));
 }
@@ -499,13 +493,11 @@ void GradientRenderer::paint(QPainter *p)
         g = QLinearGradient(pts.at(0), pts.at(1));
 
     } else if (m_gradientType == Qt::RadialGradientPattern) {
-        QLineF line(pts.at(0), pts.at(1));
-        if (line.length() > 132)
-            line.setLength(132);
-        g = QRadialGradient(line.p1(), qMin(width(), height()) / 3.0, line.p2());
+        g = QRadialGradient(pts.at(0), qMin(width(), height()) / 3.0, pts.at(1));
+
     } else {
         QLineF l(pts.at(0), pts.at(1));
-        double angle = l.angle(QLineF(0, 0, 1, 0));
+        qreal angle = l.angle(QLineF(0, 0, 1, 0));
         if (l.dy() > 0)
             angle = 360 - angle;
         g = QConicalGradient(pts.at(0), angle);
