@@ -1,43 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 2005-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
-** This file is part of the example classes of the Qt Toolkit.
+** This file is part of the examples of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** In addition, as a special exception, Nokia gives you certain
+** additional rights. These rights are described in the Nokia Qt LGPL
+** Exception version 1.0, included in the file LGPL_EXCEPTION.txt in this
+** package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -45,13 +43,16 @@
 
 #include "mainwindow.h"
 
+//! [0]
 MainWindow::MainWindow()
 {
     selectedDate = QDate::currentDate();
     fontSize = 10;
 
     QWidget *centralWidget = new QWidget;
+//! [0]
 
+//! [1]
     QLabel *dateLabel = new QLabel(tr("Date:"));
     QComboBox *monthCombo = new QComboBox;
 
@@ -61,10 +62,12 @@ MainWindow::MainWindow()
     QDateTimeEdit *yearEdit = new QDateTimeEdit;
     yearEdit->setDisplayFormat("yyyy");
     yearEdit->setDateRange(QDate(1753, 1, 1), QDate(8000, 1, 1));
+//! [1]
 
     monthCombo->setCurrentIndex(selectedDate.month() - 1);
     yearEdit->setDate(selectedDate);
 
+//! [2]
     QLabel *fontSizeLabel = new QLabel(tr("Font size:"));
     QSpinBox *fontSizeSpinBox = new QSpinBox;
     fontSizeSpinBox->setRange(1, 64);
@@ -72,12 +75,16 @@ MainWindow::MainWindow()
 
     editor = new QTextBrowser;
     insertCalendar();
+//! [2]
 
+//! [3]
     connect(monthCombo, SIGNAL(activated(int)), this, SLOT(setMonth(int)));
     connect(yearEdit, SIGNAL(dateChanged(QDate)), this, SLOT(setYear(QDate)));
     connect(fontSizeSpinBox, SIGNAL(valueChanged(int)),
             this, SLOT(setFontSize(int)));
+//! [3]
 
+//! [4]
     QHBoxLayout *controlsLayout = new QHBoxLayout;
     controlsLayout->addWidget(dateLabel);
     controlsLayout->addWidget(monthCombo);
@@ -93,20 +100,26 @@ MainWindow::MainWindow()
     centralWidget->setLayout(centralLayout);
 
     setCentralWidget(centralWidget);
+//! [4]
 }
 
+//! [5]
 void MainWindow::insertCalendar()
 {
     editor->clear();
     QTextCursor cursor = editor->textCursor();
+    cursor.beginEditBlock();
 
     QDate date(selectedDate.year(), selectedDate.month(), 1);
+//! [5]
 
+//! [6]
     QTextTableFormat tableFormat;
     tableFormat.setAlignment(Qt::AlignHCenter);
     tableFormat.setBackground(QColor("#e0e0e0"));
     tableFormat.setCellPadding(2);
     tableFormat.setCellSpacing(4);
+//! [6] //! [7]
     QVector<QTextLength> constraints;
     constraints << QTextLength(QTextLength::PercentageLength, 14)
                 << QTextLength(QTextLength::PercentageLength, 14)
@@ -116,14 +129,20 @@ void MainWindow::insertCalendar()
                 << QTextLength(QTextLength::PercentageLength, 14)
                 << QTextLength(QTextLength::PercentageLength, 14);
     tableFormat.setColumnWidthConstraints(constraints);
+//! [7]
 
+//! [8]
     QTextTable *table = cursor.insertTable(1, 7, tableFormat);
+//! [8]
 
+//! [9]
     QTextFrame *frame = cursor.currentFrame();
     QTextFrameFormat frameFormat = frame->frameFormat();
     frameFormat.setBorder(1);
     frame->setFrameFormat(frameFormat);
+//! [9]
 
+//! [10]
     QTextCharFormat format = cursor.charFormat();
     format.setFontPointSize(fontSize);
 
@@ -132,15 +151,21 @@ void MainWindow::insertCalendar()
 
     QTextCharFormat highlightedFormat = boldFormat;
     highlightedFormat.setBackground(Qt::yellow);
+//! [10]
 
+//! [11]
     for (int weekDay = 1; weekDay <= 7; ++weekDay) {
         QTextTableCell cell = table->cellAt(0, weekDay-1);
+//! [11] //! [12]
         QTextCursor cellCursor = cell.firstCursorPosition();
         cellCursor.insertText(QString("%1").arg(QDate::longDayName(weekDay)),
                               boldFormat);
     }
+//! [12]
 
+//! [13]
     table->insertRows(table->rows(), 1);
+//! [13]
 
     while (date.month() == selectedDate.month()) {
         int weekDay = date.dayOfWeek();
@@ -157,25 +182,34 @@ void MainWindow::insertCalendar()
             table->insertRows(table->rows(), 1);
     }
 
+    cursor.endEditBlock();
+//! [14]
     setWindowTitle(tr("Calendar for %1 %2"
         ).arg(QDate::longMonthName(selectedDate.month())
         ).arg(selectedDate.year()));
 }
+//! [14]
 
+//! [15]
 void MainWindow::setFontSize(int size)
 {
     fontSize = size;
     insertCalendar();
 }
+//! [15]
 
+//! [16]
 void MainWindow::setMonth(int month)
 {
     selectedDate = QDate(selectedDate.year(), month + 1, selectedDate.day());
     insertCalendar();
 }
+//! [16]
 
+//! [17]
 void MainWindow::setYear(QDate date)
 {
     selectedDate = QDate(date.year(), selectedDate.month(), selectedDate.day());
     insertCalendar();
 }
+//! [17]
